//-------------------------------------------------------------------------
// play-v6 - music player for ATmega328P @ 16 MHz
// user interface (except serial)
// by Enrico Colombini <erix@erix.it>
// license: CC Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
// http://creativecommons.org/licenses/by-sa/4.0/
//-------------------------------------------------------------------------

#ifndef INTERFACE_H
#define INTERFACE_H

#include <stdint.h>
#include <stdbool.h>
#include <avr/io.h>

//-------------------------------------------------------------------------
// constants

//buttons are connected to port D
#define BUTTON_PORT             PORTD
#define BUTTON_PORT_DDR         DDRD
#define BUTTON_PORT_PIN         PIND

//masks for both button port bits and state bits
enum ButtonMasks {
    PLAY_BUTTON_MASK = _BV(PIND4),    //(pin 2)
    NEXT_BUTTON_MASK = _BV(PIND7),    //(pin 7)
    PREV_BUTTON_MASK = _BV(PIND2),    //(pin 4)
    ALL_BUTTONS_MASK = PLAY_BUTTON_MASK | NEXT_BUTTON_MASK | PREV_BUTTON_MASK
};

//number of calls to UpdateButtons for which the input value must stay constant
#define BUTTON_DEBOUNCE_COUNT   255

//-------------------------------------------------------------------------
// public functions and macros

extern void    InitInterface(void);
extern uint8_t UpdateButtons(void);
extern bool    IsButtonPressed(uint8_t buttonMask);
extern bool    HasButtonBeenPressed(uint8_t changed, uint8_t buttonMask);
extern void    SetButtonState(uint8_t state);
extern void    CopyButtonHardwareState(void);

//-------------------------------------------------------------------------

#endif //INTERFACE_H